==> nextcloud-13.0.1.tgz: nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáře",
    "New comment …" : "Nový komentář ...",
    "Delete comment" : "Smazat komentář",
    "Post" : "Zveřejnit",
    "Cancel" : "Zrušit",
    "Edit comment" : "Upravit komentář",
    "[Deleted user]" : "[Smazaný uživatel]",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "More comments …" : "Více komentářů ...",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Povolených znaků {count} z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo k chybě při načítání komentáře s ID {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů"],
    "Comment" : "Komentář",
    "You commented" : "Okomentoval(a) jsi",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval(a)",
    "You commented on %1$s" : "Okomentoval(a) jste %1$s",
    "You commented on {file}" : "Okomentoval(a) jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v “%s”, v komentáři od uživatele, který byl později smazán",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru “{file}”, v komentáři od uživatele, který byl později smazán",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vás zmínil(a) v komentáři u %2$s",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil v komentáři u “{file}”",
    "Unknown user" : "Neznámý uživatel",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Nyní již smazaný uživatel vás zmínil v komentáři u \"{file}\""
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/cs.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Upravit komentář",
    "Delete comment" : "Smazat komentář",
    "New comment …" : "Nový komentář…",
    "Post" : "Zveřejnit",
    "Cancel" : "Storno",
    "[Deleted user]" : "[Smazaný uživatel]",
    "Comments" : "Komentáře",
    "No comments yet, start the conversation!" : "Zatím bez komentářů, začněte konverzaci!",
    "More comments …" : "Více komentářů…",
    "Save" : "Uložit",
    "Allowed characters {count} of {max}" : "Povolených znaků {count} z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo k chybě při načítání komentáře s ID {id}",
    "Error occurred while updating comment with id {id}" : "Došlo k chybě při aktualizování komentáře s id {id}",
    "Error occurred while posting comment" : "Došlo k chybě při zveřejňování komentáře",
    "_%n unread comment_::_%n unread comments_" : ["%n nepřečtený komentář","%n nepřečtené komentáře","%n nepřečtených komentářů","%n nepřečtených komentářů"],
    "Comment" : "Komentář",
    "You commented" : "Okomentovali jste",
    "%1$s commented" : "%1$s okomentován",
    "{author} commented" : "{author} okomentoval",
    "You commented on %1$s" : "Okomentoval(a) jste %1$s",
    "You commented on {file}" : "Okomentoval(a) jste {file}",
    "%1$s commented on %2$s" : "%1$s okomentoval %2$s",
    "{author} commented on {file}" : "{author} okomentoval(a) {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáře</strong> souborů",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v “%s”, v komentáři od uživatele, který byl později smazán",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Byli jste zmíněni v souboru “{file}”, v komentáři od uživatele, který byl později smazán",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s vás zmínil(a) v komentáři u %2$s",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás zmínil v komentáři u “{file}”",
    "Unknown user" : "Neznámý uživatel",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Nyní již smazaný uživatel vás zmínil v komentáři u \"{file}\""
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
